import java.util.ArrayList;
import java.util.Random;

/**
 * Implements the functionality necessary for the coin game
 * @author alchambers
 * @version sp19
 */
public class CoinGame{
    private final int UPPERBOUND = 25;

    private int leftIndex; // stores the index of the leftmost available coin
    private int rightIndex; // stores the index of the rightmost available coin

    private int player1Score;
    private int player2Score;
    
    private ArrayList<Coin> strip;
   
    /**
     * Initializes the coin strip
     * 
     * @param stripLength
     *              The length of the strip
     */
    public CoinGame(int stripLength){
        leftIndex = 0;
        rightIndex = stripLength-1;

        player1Score = 0;
        player2Score = 0;

        ArrayList<Coin> strip = new ArrayList<Coin>();  
        Random rng = new Random();
        int i = 0;
        while(i <= stripLength){
            int randomDenom = rng.nextInt(UPPERBOUND)+1;
            Coin newCoin = new Coin(randomDenom);
            this.strip.add(newCoin);
            i++;
        }        
    }

    /**
     * Updates the game to reflect that the player has chosen the left-
     * or rightmost coin
     * 
     * @param choice
     *              Either "left" or "right"
     * @param player
     *              Either 0 or 1 representing the two players
     */
    public void chooseCoin(String choice, int player){
        Coin chosen;
        if(choice == "left"){
            leftIndex++;  
            chosen = strip.get(leftIndex); // get the coin
            chosen.setTaken();             // mark it as taken                 
        }else{
            rightIndex--;                   // update our rightmost index            
            chosen = strip.get(rightIndex); // get the coin
            chosen.setTaken();              // mark it as taken                        
        }   

        if(player == 0){
            player1Score += chosen.getDenomination();
        }
        else{
            player2Score += chosen.getDenomination();
        }
    }

    /**
     * Returns the current score for the given player
     * 
     * @param player
     *              Either 0 or 1 representing a player
     *              
     * @return The current score for the given player 
     */
    public int total(int player){
        if(player == 0){
            return player1Score;
        }
        else{
            return player2Score;
        }
    }
        
    /**
     * Prints a string representation of the game board
     * 
     * @return A string representation of the game board
     */
    public String toString(){
        String str = "[";
        
        int i = 0;       
        while(i < strip.size()){ // notice I am only going to size - 1 
            Coin coin = strip.get(i);
            if(coin.isTaken()){
                str += toPrint(i) + ",";
            }
            else{
                str += toPrint(i) + ",";
            }
            i++;
        }
        
        // I am doing the last iteration outside of the loop because of the comma 
        str += toPrint(strip.size()-1) + "]";
        return str;
    }

    
    /*
     *       Private Helper Methods
     */
    private String toPrint(int index){
        Coin coin = strip.get(index);
        if(coin.isTaken()){
            return "--";
        }
        else{
            return coin.getDenomination() + ""; // a trick for converting an int to a String
        }
    }
}


